﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Web;
using System.Web.UI;
using System.ComponentModel;
using BlogEngine.Core;

namespace App_Code.Controls
{
    //Original developed by Paul Tumelty - http://www.tumelty.com/
    //Changed by Krishnan - http://geekiest.net
    // Picks a random post and generates a link to it
    public class RandomPost : Control {

        /// <summary>
        /// Use this to specify the number of random posts to display default is 1
        /// </summary>
        [DefaultValue("1")]
        public int LinkCount
        {
            get {
                object linkTitle = ViewState["LinkCount"];
                if (linkTitle != null)
                    return (int)linkTitle;
                else
                    return 0;
            }
            set {
                ViewState["LinkCount"] = value;
            }
        }

        // <summary>
        /// Use this to specify the title of the link, default is ""
        /// </summary>
        [DefaultValue("")]
        public string LinkTitle
        {
            get
            {
                object linkTitle = ViewState["LinkTitle"];
                if (linkTitle != null)
                    return (string)linkTitle;
                else
                    return string.Empty;
            }
            set
            {
                ViewState["LinkTitle"] = value;
            }
        }
        

        /// <summary>
        /// Retrieves a random post from the posts
        /// </summary>
        /// <returns></returns>
        public BlogEngine.Core.Post GetRandomPost(int count) {

            int iPostCount = Post.Posts.Count;

            int randomcount = 0;
            Random rand = new Random();

            for (int i = 0; i <= count; i++)
            {
                randomcount=rand.Next(rand.Next(0, iPostCount),iPostCount);
            }
            return Post.Posts[randomcount];
        }

        /// <summary>
        /// Renders the HTML to display the random post
        /// </summary>
        /// <param name="writer"></param>
        protected override void Render(HtmlTextWriter writer)
        {


            writer.BeginRender();
            writer.RenderBeginTag(HtmlTextWriterTag.Ul);
            for (int i = 0; i < LinkCount; i++)
            {
                Post oPost = GetRandomPost(i);

                writer.RenderBeginTag(HtmlTextWriterTag.Li);
                writer.AddAttribute(HtmlTextWriterAttribute.Href, oPost.RelativeLink);

                writer.RenderBeginTag(HtmlTextWriterTag.A);
                if (LinkTitle == "")
                {
                    writer.Write(oPost.Title);
                }
                else
                {
                    if (LinkCount == 1)
                    {
                        writer.Write(LinkTitle);
                    }
                    else
                    {
                        writer.Write(LinkTitle + " " + (i + 1).ToString());
                    }
                }
                writer.RenderEndTag();
                writer.RenderEndTag();

            }
            writer.RenderEndTag();
            writer.EndRender();

            base.Render(writer);
        }
    }
}
